package com.huashe.park.core.service;

import com.huashe.park.domain.entity.ConsMachineCmdHis;

import java.util.List;

/**
 * 桩机指令下发历史Service接口
 * 
 * @author ruoyi
 * @date 2025-02-12
 */
public interface IConsMachineCmdHisService 
{
    /**
     * 查询桩机指令下发历史
     * 
     * @param id 桩机指令下发历史主键
     * @return 桩机指令下发历史
     */
    public ConsMachineCmdHis selectConsMachineCmdHisById(Long id);

    /**
     * 查询桩机指令下发历史列表
     * 
     * @param consMachineCmdHis 桩机指令下发历史
     * @return 桩机指令下发历史集合
     */
    public List<ConsMachineCmdHis> selectConsMachineCmdHisList(ConsMachineCmdHis consMachineCmdHis);

    /**
     * 新增桩机指令下发历史
     * 
     * @param consMachineCmdHis 桩机指令下发历史
     * @return 结果
     */
    public int insertConsMachineCmdHis(ConsMachineCmdHis consMachineCmdHis);

    /**
     * 修改桩机指令下发历史
     * 
     * @param consMachineCmdHis 桩机指令下发历史
     * @return 结果
     */
    public int updateConsMachineCmdHis(ConsMachineCmdHis consMachineCmdHis);

    /**
     * 批量删除桩机指令下发历史
     * 
     * @param ids 需要删除的桩机指令下发历史主键集合
     * @return 结果
     */
    public int deleteConsMachineCmdHisByIds(Long[] ids);

    /**
     * 删除桩机指令下发历史信息
     * 
     * @param id 桩机指令下发历史主键
     * @return 结果
     */
    public int deleteConsMachineCmdHisById(Long id);
}
